@@ -37,7 +37,7 @@ import yaml
 from jsonschema.validators import validator_for
 
 from .kasusererror import KasUserError
-from . import __file_version__, __compatible_file_version__
+from . import __file_version__, __compatible_file_version__, __version__
 from . import CONFIGSCHEMA
 
 __license__ = 'MIT'
@@ -45,6 +45,8 @@ __copyright__ = 'Copyright (c) Siemens AG, 2017-2021'
 
 SOURCE_DIR_OVERRIDE_KEY = '_source_dir'
 SOURCE_DIR_HOST_OVERRIDE_KEY = '_source_dir_host'
+PROJECT_CONFIG_URL = f'https://kas.readthedocs.io/en/{__version__}/' \
+    'userguide/project-configuration.html'
 
 
 class LoadConfigException(KasUserError):
@@ -75,11 +77,15 @@ def load_config(filename):
     validator = validator_class(CONFIGSCHEMA)
     validation_error = False
 
-    for error in validator.iter_errors(config):
+    for error in sorted(validator.iter_errors(config), key=str):
         validation_error = True
-        logging.error('Config file validation Error:\n%s', error)
+        logging.error('Config file validation Error:\n%s', error.message)
+        logging.error('For a list of supported configuration elements, see %s',
+                      PROJECT_CONFIG_URL)
 
     if validation_error:
+        logging.debug('Validation against this schema failed:\n%s',
+                      json.dumps(error.schema, indent=2))
         raise LoadConfigException('Error(s) occured while validating the '
                                   'config file', filename)
 
@@ -259,7 +265,9 @@ class IncludeHandler:
 
         def _internal_dict_merge(dest, upd):
             """
-            Merges upd recursively into a copy of dest as OrderedDict
+            Merges upd recursively into a copy of dest. The order is preserved
+            as in the original dict as dict-insertion orders are preserved from
+            Python 3.6 onwards.
 
             If keys in upd intersect with keys in dest we will do a manual
             merge (helpful for non-dict types like FunctionWrapper).
@@ -267,7 +275,7 @@ class IncludeHandler:
             if (not isinstance(dest, Mapping)) \
                     or (not isinstance(upd, Mapping)):
                 raise IncludeException('Cannot merge using non-dict')
-            dest = OrderedDict(dest)
+            dest = dest.copy()
             updkeys = list(upd.keys())
             if set(list(dest.keys())) & set(updkeys):
                 for key in updkeys:
@@ -304,4 +312,8 @@ class IncludeHandler:
 
         config = functools.reduce(_internal_dict_merge,
                                   map(lambda x: x[1], configs))
+        # the merged config must have the highest (used) version number
+        header_version = max([int(cfg['header']['version'])
+                              for _, cfg in configs])
+        config['header']['version'] = header_version
         return config, missing_repos
