@@ -23,11 +23,11 @@
     This module is the main entry point for kas, setup tool for bitbake based
     projects. In case of user errors (e.g. invalid configuration, repo fetch
     failure) kas exits with error code 2, while exiting with 1 for internal
-    errors. For details on error handling, see :mod:`kas.kasusererror`.
+    errors. When cancelled by SIGINT, kas exits with 130. For details on error
+    handling, see :mod:`kas.kasusererror`.
 """
 
 import argparse
-import atexit
 import asyncio
 import traceback
 import logging
@@ -48,7 +48,7 @@ from . import plugins
 __license__ = 'MIT'
 __copyright__ = 'Copyright (c) Siemens AG, 2017-2018'
 
-default_log_level = 'info'
+DEFAULT_LOG_LEVEL = 'info'
 
 
 def create_logger():
@@ -56,7 +56,7 @@ def create_logger():
         Setup the logging environment
     """
     log = logging.getLogger()  # root logger
-    log.setLevel(logging.getLevelName(default_log_level.upper()))
+    log.setLevel(DEFAULT_LOG_LEVEL.upper())
     format_str = '%(asctime)s - %(levelname)-8s - %(message)s'
     date_format = '%Y-%m-%d %H:%M:%S'
     if HAVE_COLORLOG and os.isatty(2):
@@ -76,37 +76,57 @@ def create_logger():
     return logging.getLogger(__name__)
 
 
+def cleanup_logger():
+    """
+        Cleanup the logging environment
+    """
+    for handler in logging.root.handlers[:]:
+        if isinstance(handler, logging.StreamHandler):
+            logging.root.removeHandler(handler)
+
+
+def get_pending_tasks(loop):
+    try:
+        return asyncio.all_tasks(loop)
+    except AttributeError:
+        # for Python < 3.7
+        return asyncio.Task.all_tasks(loop)
+
+
 def interruption():
     """
-        Ignore SIGINT/SIGTERM in kas, let them be handled by our sub-processes
+        Gracefully cancel all tasks in the event loop
     """
-    pass
+    loop = asyncio.get_event_loop()
+    for sig in [signal.SIGINT, signal.SIGTERM]:
+        loop.remove_signal_handler(sig)
+        loop.add_signal_handler(sig, termination)
+    pending = get_pending_tasks(loop)
+    if pending:
+        logging.debug(f'waiting for {len(pending)} tasks to terminate')
+    [t.cancel() for t in pending]
 
 
-def _atexit_handler():
+def termination():
+    """
+        Forcefully terminate the process
+    """
+    logging.error('kas terminated forcefully')
+    os._exit(130)
+
+
+def shutdown_loop(loop):
     """
         Waits for completion of the event loop
     """
+    pending = get_pending_tasks(loop)
+    # Ignore exceptions in final shutdown (Python3.6 workaround).
+    # These are related to the cancellation of tasks.
     try:
-        loop = asyncio.get_running_loop()
-        pending = asyncio.all_tasks(loop)
-    except RuntimeError:
-        # no running loop anymore, nothing to do
-        return
-    except AttributeError:
-        # for Python < 3.7
-        loop = asyncio.get_event_loop()
-        pending = asyncio.Task.all_tasks(loop)
-    if not loop.is_closed():
-        # this code path is observed on older python versions (e.g. 3.6).
-        # In case the loop is not yet closed, tasks still might throw
-        # exceptions, but we are not interested in these as they are
-        # likely due to the cancellation. By that, we simply drop them.
-        try:
-            loop.run_until_complete(asyncio.gather(*pending))
-        except KasUserError:
-            pass
-        loop.close()
+        loop.run_until_complete(asyncio.gather(*pending))
+    except KasUserError:
+        pass
+    loop.close()
 
 
 def kas_get_argparser():
@@ -127,16 +147,11 @@ def kas_get_argparser():
              f'earliest compatible version {__compatible_file_version__})'
     parser.add_argument('--version', action='version', version=verstr)
 
-    parser.add_argument('-d', '--debug',
-                        action='store_const', const='debug', dest='log_level',
-                        help='Enable debug logging (deprecated, use '
-                             '--log-level debug).')
-
     parser.add_argument('-l', '--log-level',
                         choices=['debug', 'info', 'warning', 'error',
                                  'critical'],
-                        default=f'{default_log_level}',
-                        help=f'Set log level (default: {default_log_level})')
+                        default=f'{DEFAULT_LOG_LEVEL}',
+                        help=f'Set log level (default: {DEFAULT_LOG_LEVEL})')
 
     subparser = parser.add_subparsers(help='sub command help', dest='cmd')
 
@@ -177,23 +192,40 @@ def kas(argv):
     args = parser.parse_args(argv)
 
     if args.log_level:
-        level_num = logging.getLevelName(args.log_level.upper())
-        logging.getLogger().setLevel(level_num)
+        logging.getLogger().setLevel(args.log_level.upper())
 
     logging.info('%s %s started', os.path.basename(sys.argv[0]), __version__)
 
-    loop = asyncio.get_event_loop()
+    loop = asyncio.new_event_loop()
+    asyncio.set_event_loop(loop)
 
-    for sig in (signal.SIGINT, signal.SIGTERM):
-        loop.add_signal_handler(sig, interruption)
-    atexit.register(_atexit_handler)
+    loop.add_signal_handler(signal.SIGTERM, interruption)
+    # don't overwrite pytest's signal handler
+    if "PYTEST_CURRENT_TEST" not in os.environ:
+        loop.add_signal_handler(signal.SIGINT, interruption)
 
-    plugin_class = plugins.get(args.cmd)
-    if plugin_class:
-        plugin = plugin_class()
-        plugin.run(args)
-    else:
-        parser.print_help()
+    try:
+        plugin_class = plugins.get(args.cmd)
+        if plugin_class:
+            plugin = plugin_class()
+            plugin.run(args)
+        else:
+            parser.print_help()
+    except CommandExecError as err:
+        logging.error('%s', err)
+        raise
+    except KasUserError as err:
+        logging.error('%s', err)
+        raise
+    except asyncio.CancelledError:
+        logging.error('kas execution cancelled')
+        raise
+    except Exception as err:
+        logging.error('%s', err)
+        raise
+    finally:
+        shutdown_loop(loop)
+        cleanup_logger()
 
 
 def main():
@@ -204,13 +236,12 @@ def main():
     try:
         kas(sys.argv[1:])
     except CommandExecError as err:
-        logging.error('%s', err)
         sys.exit(err.ret_code if err.forward else 2)
-    except KasUserError as err:
-        logging.error('%s', err)
+    except KasUserError:
         sys.exit(2)
-    except Exception as err:
-        logging.error('%s', err)
+    except asyncio.CancelledError:
+        sys.exit(130)
+    except Exception:
         traceback.print_exc()
         sys.exit(1)
 
