@@ -66,3 +66,19 @@ class ArgsCombinationError(KasUserError):
     """
     def __init__(self, message):
         super().__init__(f'Invalid combination of arguments: {message}')
+
+
+class ArtifactNotFoundError(KasUserError, FileNotFoundError):
+    """
+    A configured artifact is not found (or the glob matches 0 elements).
+    """
+    def __init__(self, name, artifact):
+        super().__init__(f'No artifact found for {name}:"{artifact}"')
+
+
+class MissingModuleError(KasUserError):
+    """
+    An optional module is missing for the requested operation
+    """
+    def __init__(self, module, operation) -> None:
+        super().__init__(f'Module "{module}" is required for: {operation}')
