@@ -157,6 +157,18 @@ class Repo:
                               cwd=self.path, fail=False)
         return bool(output)
 
+    @staticmethod
+    def get_type():
+        """
+            Repo type as defined in spdx-spec/v2.3/package-information
+        """
+        raise NotImplementedError("Repo type not implemented")
+
+    def contains_path(self, path):
+        (ret, _) = run_cmd(self.contains_path_cmd(str(path)),
+                           cwd=self.path, fail=False)
+        return ret == 0
+
     def __str__(self):
         if self.commit and (self.tag or self.branch):
             refspec = f'{self.commit}({self.tag or self.branch})'
@@ -406,12 +418,13 @@ class RepoImpl(Repo):
                 raise RepoRefError(f'Tag "{self.tag}" cannot be found '
                                    f'in repository "{self.name}"')
 
-            if self.commit and output.strip() != self.commit:
+            desired_ref = output.strip()
+            if self.commit and desired_ref != self.commit:
                 # Ensure provided commit and tag match
-                raise RepoRefError(f'Provided tag "{self.tag}" does not match '
+                raise RepoRefError(f'Provided tag "{self.tag}" '
+                                   f'("{desired_ref}") does not match '
                                    f'provided commit "{self.commit}" in '
                                    f'repository "{self.name}", aborting!')
-            desired_ref = output.strip()
             is_branch = False
         elif self.branch:
             (retc, output) = run_cmd(self.resolve_branch_cmd(),
@@ -521,7 +534,8 @@ class RepoImpl(Repo):
                     "%a, %d %b %Y %H:%M:%S %z")
 
             env = get_context().environ.copy()
-            cmd = self.commit_cmd(env, 'kas <kas@example.com>', 'msg',
+            msg = f'kas: {patch_id}\n\npatch {path} applied by kas'
+            cmd = self.commit_cmd(env, 'kas <kas@example.com>', msg,
                                   timestamp)
             (retc, output) = await run_cmd_async(
                 cmd, cwd=self.path, env=env, fail=False)
@@ -620,7 +634,7 @@ class GitRepo(RepoImpl):
         return cmd
 
     def is_dirty_cmd(self):
-        return ['git', 'status', '-s']
+        return ['git', 'diff', '--stat']
 
     def resolve_branch_cmd(self):
         refspec = self.remove_ref_prefix(self.branch or self.refspec)
@@ -667,6 +681,9 @@ class GitRepo(RepoImpl):
         if date and date.startswith("Date: "):
             return date.replace("Date: ", "").strip()
 
+    def contains_path_cmd(self, path):
+        return ['git', 'ls-files', '--error-unmatch', path]
+
 
 class MercurialRepo(RepoImpl):
     """
@@ -675,7 +692,7 @@ class MercurialRepo(RepoImpl):
 
     @staticmethod
     def get_type():
-        return 'mercurial'
+        return 'hg'
 
     def add_cmd(self):
         return ['hg', 'add']
@@ -697,7 +714,8 @@ class MercurialRepo(RepoImpl):
         return ['hg', 'pull']
 
     def is_dirty_cmd(self):
-        return ['hg', 'status']
+        return ['hg', 'status', '--modified', '--added',
+                '--removed', '--deleted']
 
     def resolve_branch_cmd(self):
         if self.branch:
@@ -746,3 +764,6 @@ class MercurialRepo(RepoImpl):
 
         if date and date.startswith("# "):
             return date.replace("# ", "").strip()
+
+    def contains_path_cmd(self, path):
+        return ['hg', 'files', path]
