@@ -33,9 +33,11 @@ def dokas(monkeykas, tmpdir):
     tdir = str(tmpdir / 'test_layers')
     shutil.copytree('tests/test_layers', tdir)
     monkeykas.chdir(tdir)
+    monkeykas.setenv('KAS_CLONE_DEPTH', '1')
     kas.kas(['shell', 'test.yml', '-c', 'true'])
 
 
+@pytest.mark.online
 def test_layers_default(dokas):
     match = 0
     with open('build/conf/bblayers.conf', 'r') as f:
@@ -45,6 +47,7 @@ def test_layers_default(dokas):
     assert match == 1
 
 
+@pytest.mark.online
 def test_layers_include(dokas):
     match = 0
     with open('build/conf/bblayers.conf', 'r') as f:
@@ -54,14 +57,28 @@ def test_layers_include(dokas):
     assert match == 2
 
 
+@pytest.mark.online
 def test_layers_exclude(dokas):
     with open('build/conf/bblayers.conf', 'r') as f:
         for line in f:
             assert f'{LAYERBASE}/kas2' not in line
 
 
+@pytest.mark.online
 def test_layers_strip_dot(dokas):
     with open('build/conf/bblayers.conf', 'r') as f:
         lines = f.readlines()
         assert any(f'{LAYERBASE}/kas3 ' in x for x in lines)
         assert any(f'{LAYERBASE}/kas3/meta-bar' in x for x in lines)
+
+
+@pytest.mark.online
+def test_layers_order(dokas):
+    with open('build/conf/bblayers.conf', 'r') as f:
+        layers = [x.strip(' \\"\n').replace(LAYERBASE, '')
+                  for x in f.readlines() if x.lstrip().startswith(LAYERBASE)]
+        # layers of a repo are sorted alphabetically
+        assert layers[1] == '/kas1/meta-bar'
+        assert layers[2] == '/kas1/meta-foo'
+        # repos are sorted alphabetically (aa-kas from kas4 is last)
+        assert layers[-1] == '/aa-kas/meta'
