@@ -22,11 +22,28 @@
 
 import pytest
 import shutil
+import yaml
+import subprocess
 from kas import kas
-from kas.libkas import run_cmd
 from kas.repos import RepoRefError, Repo
 
 
+def run_cmd(cmd, cwd=None, fail=True):
+    """
+        Run a command and return the return code and output.
+        Replacement for kas internal run_cmd function which
+        cannot be used outside of kas as there is no event loop.
+    """
+    try:
+        output = subprocess.check_output(cmd, cwd=cwd)
+        return (0, output.decode('utf-8'))
+    except subprocess.CalledProcessError as e:
+        if fail:
+            raise e
+        return (e.returncode, e.output.decode('utf-8'))
+
+
+@pytest.mark.online
 def test_refspec_switch(monkeykas, tmpdir):
     """
         Test that the local git clone is correctly updated when switching
@@ -77,6 +94,7 @@ def test_refspec_switch(monkeykas, tmpdir):
     assert output.strip() == '2.6.3'
 
 
+@pytest.mark.online
 def test_refspec_absolute(monkeykas, tmpdir):
     """
         Test that the local git clone works when a absolute refspec
@@ -130,6 +148,7 @@ def test_commit_refspec_mix(monkeykas, tmpdir):
         kas.kas(['shell', 'test7.yml', '-c', 'true'])
 
 
+@pytest.mark.online
 def test_tag_commit_do_not_match(monkeykas, tmpdir):
     """
         Test that giving tag and commit that do not match raises an error.
@@ -141,6 +160,7 @@ def test_tag_commit_do_not_match(monkeykas, tmpdir):
         kas.kas(['shell', 'test8.yml', '-c', 'true'])
 
 
+@pytest.mark.online
 def test_unsafe_tag_warning(capsys, monkeykas, tmpdir):
     """
         Test that using tag without commit issues a warning, but only once.
@@ -156,6 +176,7 @@ def test_unsafe_tag_warning(capsys, monkeykas, tmpdir):
         'are mutable.') == 1
 
 
+@pytest.mark.online
 def test_tag_branch_same_name(capsys, monkeykas, tmpdir):
     """
         Test that kas uses the tag if a branch has the same name as the tag.
@@ -203,6 +224,7 @@ def test_tag_branch_same_name(capsys, monkeykas, tmpdir):
     assert output.strip() == output2.strip()
 
 
+@pytest.mark.online
 def test_refspec_warning(capsys, monkeykas, tmpdir):
     """
         Test that using legacy refspec issues a warning, but only once.
@@ -217,15 +239,34 @@ def test_refspec_warning(capsys, monkeykas, tmpdir):
         'Using deprecated refspec for repository "kas2".') == 1
 
 
-def test_branch_and_tag(monkeykas, tmpdir):
+@pytest.mark.online
+def test_branch_and_tag(monkeykas, tmpdir, mercurial):
     """
         Test if error is raised when branch and tag are set.
     """
     tdir = str(tmpdir / 'test_branch_and_tag')
     shutil.copytree('tests/test_refspec', tdir)
     monkeykas.chdir(tdir)
+    with mercurial(tmpdir, 'evolve', branch='stable'):
+        with pytest.raises(RepoRefError):
+            kas.kas(['checkout', 'test9.yml'])
+
     with pytest.raises(RepoRefError):
         kas.kas(['checkout', 'test10.yml'])
 
     with pytest.raises(RepoRefError):
         kas.kas(['checkout', 'test11.yml'])
+
+
+@pytest.mark.online
+def test_commit_expand(monkeykas, tmpdir, capsys):
+    """
+        Test if an abbreviated commit hash is expanded to the full hash.
+    """
+    tdir = str(tmpdir / 'test_commit_expand')
+    shutil.copytree('tests/test_refspec', tdir)
+    monkeykas.chdir(tdir)
+    kas.kas(['dump', '--resolve-refs', 'test12.yml'])
+    rawspec = yaml.safe_load(capsys.readouterr().out)
+    assert rawspec['repos']['kas']['commit'] == \
+        'abd109469d17b7ff4d958b5aa5ab5f5511cc4d43'
